# README

一个基于 `Koa` 托管 Node.js 云函数的框架，使用该框架可以将函数部署至容器环境中，或在本地调试。Node.js 最小依赖版本 `>=18.0.0`。

参考 [示例](./examples) 了解如何使用。

## 参数说明

| 命令行参数         | 环境变量           | 默认值                              | 示例                     | 说明                                                                                              |
| ------------------ | ------------------ | ----------------------------------- | ------------------------ | ------------------------------------------------------------------------------------------------- |
| --port             | PORT               | 3000                                | --port=3000              | 监听的端口                                                                                        |
| --target           | FUNCTION_TARGET    | main                                | --target=hello           | 目标函数名称                                                                                      |
| --source           | FUNCTION_SOURCE    | index.js or index.cjs or index.mjs    | --source=main.mjs        | 目标函数文件名 |
| --signatureType    | SIGNATURE_TYPE     | event                               | --signatureType=event    | 函数格式，当前仅支持`event`                                                                       |
| --gracefulShutdown | GRACEFUL_SHUTDOWN  | true                                | --gracefulShutdown=false | 是否启用服务的优雅停止                                                                            |
| /                  | KILL_TIMEOUT       | 5000                                | KILL_TIMEOUT=60000       | 优雅停止时，等待请求处理完成的超时时间                                                            |
| --timeout          | TIMEOUT            | 0                                   | --timeout=5000           | Node.js Server 超时时间，见 <https://nodejs.org/api/http.html#servertimeout>                      |
| --keepAliveTimeout | KEEP_ALIVE_TIMEOUT | 65000                               | --keepAliveTimeout=10000 | Node.js Server keep-alive 超时时间，见 <https://nodejs.org/api/http.html#server-keepalivetimeout> |
| --captureStack     | CAPTURE_STACK      | `NODE_ENV` 不为 `production` 时开启 | --captureStack=true      | 请求出错时，是否返回错误堆栈                                                                      |
| --concurrencyLimit | CONCURRENCY_LIMIT  | 0                                   | --concurrencyLimit=100   | 并发请求数限制，0 为不限制                                                                        |
| --noExit           | NO_EXIT            | false                               | --noExit=true            | 是否禁用 `process.exit()` 避免进程意外退出                                                        |
| --logHeaderBody    | LOG_HEADER_BODY    | false                               | --logHeaderBody=true     | 是否在请求日志中记录请求头、请求体、响应头、响应体，如记录，将会限制 body 大小为 2KB              |
| --dry-run          | /                  | false                               | --dry-run                | 是否不启动服务，只验证代码可以正常加载                                                            |
| --logDirname      | LOG_DIRNAME        | ./logs                                | --logDirname=/var/logs     | 日志文件目录                                                                                      |
| --maxLogFileSize  | MAX_LOG_FILE_SIZE  | `1024 * 1024 * 128`(128m)                     | --maxLogFileSize=`2097152` |  单个日志文件最大字节数                                                                                   |
| --maxLogFiles     | MAX_LOG_FILES      | 4                                   | --maxLogFiles=5          | 最多同时存在的日志文件数量                                                                                  |
| -w, --watch        | /              | false                               | -w                      | 是否启用热重启模式，如启用，将会在文件变更时自动重启服务                                              |
